/* Copyright (C) 2011, 2012, 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.artifacts.states;

import org.apache.log4j.Logger;
import org.dive4elements.artifacts.Artifact;
import org.dive4elements.artifacts.CallContext;
import org.dive4elements.artifacts.CallMeta;
import org.dive4elements.artifacts.common.utils.XMLUtils;
import org.dive4elements.river.artifacts.resources.Resources;
import org.w3c.dom.Element;

/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
// FIXME: inherit from BooleanChoiceState instead to remove duplicate code; BUT: this will probably break artifact
// serialization
public class FloodplainChoice extends DefaultState {

    public static final String OPTION = "floodplain.option";
    public static final String ACTIVE = "floodplain.active";
    public static final String INACTIVE = "floodplain.inactive";

    private static final Logger log = Logger.getLogger(FloodplainChoice.class);

    @Override
    protected String getUIProvider() {
        return "boolean_panel";
    }

    @Override
    protected Element[] createItems(final XMLUtils.ElementCreator cr, final Artifact artifact, final String name, final CallContext context) {
        final CallMeta meta = context.getMeta();

        final Element option = createItem(cr, new String[] { Resources.getMsg(meta, OPTION, OPTION), "true" });

        return new Element[] { option };
    }

    @Override
    protected String getLabelFor(final CallContext cc, final String name, final String value, final String type) {
        log.debug("GET LABEL FOR '" + name + "' / '" + value + "'");
        if (value != null && value.equals("true")) {
            return Resources.getMsg(cc.getMeta(), ACTIVE, ACTIVE);
        } else {
            return Resources.getMsg(cc.getMeta(), INACTIVE, INACTIVE);
        }
    }

    // ist mit super identisch!
    // protected Element createItem(XMLUtils.ElementCreator cr, Object obj) {
    // Element item = ProtocolUtils.createArtNode(cr, "item", null, null);
    // Element label = ProtocolUtils.createArtNode(cr, "label", null, null);
    // Element value = ProtocolUtils.createArtNode(cr, "value", null, null);
    //
    // String[] arr = (String[]) obj;
    //
    // label.setTextContent(arr[0]);
    // value.setTextContent(arr[1]);
    //
    // item.appendChild(label);
    // item.appendChild(value);
    //
    // return item;
    // }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
